BaseKey class

This class represents a keyboard key with platform-specific identifiers.

Properties:

  • logicalKeyId - The logical key identifier from Darts's keyboard API
  • description - A human-readable description of the key
  • linux - The Linux-specific key identifier (can be null)
  • windows - The Windows-specific key identifier (can be null)
  • mac - The MacOS-specific key identifier (can be null)

Example:

var spaceKey = BaseKey(
  LogicalKeyboardKey.space, // The value of darts Key
  "Space",                  // Defines the description for the key
  "space",                  // The Linux value
  32,                       // The Windows value
  49                        // The MacOs Value
);
Implementers

Constructors

BaseKey(LogicalKeyboardKey? logicalKeyId, String? description, String? linux, int? windows, int? mac)
const

Properties

description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
linux → String?
final
logicalKeyId → LogicalKeyboardKey?
final
mac → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
windows → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited